# CompoundWidgets
Custom widgets based on tkinter/ttk/ttkbootstrap libraries.

To be used in conjunction with tkinter, tkinter.ttk and ttkbootstrap Style.

Intends to help create widgets on the following formats:

. label + entry

. label + combobox

. label + spinbox

. label + text

. label + entry + combobox

Also creates new style of buttons ("led" like buttons). The following are available:

. CheckLedButton

. LedButton

. RadioLedButton

Has two frames with additional properties:

. CollapsableFrame

. ScrollableFrame


Includes the entry validation required methods for "numbers only" and for maximum number of characters. 

